@@ -12,13 +12,23 @@ from botocore.config import Config as BotoConfig
 from botocore.exceptions import ClientError, ConnectionError, ProfileNotFound, WaiterError
 
 from ..decorators import retry
-from ..errors import BotoError, CliError, OfflineError
+from ..errors import (
+    AccessDenied,
+    BotoError,
+    CliError,
+    ExpiredCredentials,
+    OfflineError,
+    TargetNotConnected,
+    raise_if_match,
+)
 from .config import SymConfigFile
 from .params import get_ssh_user
 
 InstanceIDPattern = re.compile("^i-[a-f0-9]+$")
 UnauthorizedError = re.compile(r"UnauthorizedOperation")
-RequestExpired = re.compile(r"RequestExpired|ExpiredTokenException")
+RequestExpired = re.compile(r"RequestExpired|ExpiredToken")
+TargetNotConnectedPattern = re.compile("TargetNotConnected")
+AccessDeniedPattern = re.compile("AccessDeniedException")
 
 
 def intercept_boto_errors(f):
@@ -33,11 +43,15 @@ def intercept_boto_errors(f):
                 raise BotoError(
                     err, f"Does your user role have permission to {err.operation_name}?"
                 )
-            if RequestExpired.search(str(err)):
-                raise BotoError(
-                    err,
-                    f"Your AWS credentials have expired. Try running `sym write-creds` again.",
-                )
+
+            raise_if_match(
+                {
+                    TargetNotConnectedPattern: TargetNotConnected,
+                    AccessDeniedPattern: AccessDenied,
+                    RequestExpired: ExpiredCredentials,
+                },
+                str(err),
+            )
 
             raise CliError(str(err)) from err
         except ProfileNotFound as err:
