@@ -4,8 +4,8 @@ from typing import List, Mapping, MutableMapping, Optional, TypedDict
 
 import immutables
 
+from sym.cli.helpers.config import sym_config_file
 from sym.cli.helpers.config.base import ConfigBase, fail_ok
-from sym.cli.helpers.config.sym_config_file import _Config
 
 
 class ServerConfigSchema(TypedDict):
@@ -39,9 +39,13 @@ class Config(ConfigBase[ConfigSchema]):
     def get_instance(cls, instance: str) -> Optional[ServerConfigSchema]:
         return cls.get_servers().get(instance)
 
-    @classmethod
-    def get_cli_name(cls) -> str:
-        config_dir = _Config.dir_name
+    @staticmethod
+    def get_dir_name() -> str:
+        return sym_config_file.get_dir_name()
+
+    @staticmethod
+    def get_cli_name() -> str:
+        config_dir = sym_config_file.get_dir_name()
         if config_dir == "symflow":
             return "sym-flow-cli"
         elif config_dir == "sym":
