@@ -2,7 +2,7 @@ from typing import Dict, List, NamedTuple, Optional, Tuple, TypedDict
 
 import validators
 
-from ..errors import CliError, InvalidResource
+from ..errors import CliError, InvalidResource, MissingResource
 from .config import Config
 
 
@@ -192,7 +192,7 @@ def get_org_params() -> OrgParams:
 
 def get_aws_saml_url(resource: str) -> str:
     org_params = get_org_params()
-    profile = org_params["profiles"][resource]
+    profile = get_profile(resource)
     return profile.aws_saml_url or org_params["aws_saml_url"]
 
 
@@ -228,6 +228,8 @@ def get_resource_env_vars() -> Optional[str]:
 
 
 def get_profile_and_name(resource: str) -> Tuple[str, Profile]:
+    if not resource:
+        raise MissingResource(list(get_profiles().keys()))
     try:
         return next(
             (name, profile)
@@ -235,7 +237,7 @@ def get_profile_and_name(resource: str) -> Tuple[str, Profile]:
             if resource == name or resource in profile.aliases
         )
     except StopIteration:
-        raise InvalidResource(resource, get_profiles().keys())
+        raise InvalidResource(resource, list(get_profiles().keys()))
 
 
 def get_profile(resource: str) -> Profile:
