@@ -4,8 +4,6 @@ from functools import cached_property
 from pathlib import Path
 from typing import Iterator, Tuple
 
-from sym.cli.errors import InvalidResource
-
 from ..decorators import command_require_bins, intercept_errors, run_subprocess
 from ..helpers.boto import get_identity
 from ..helpers.contexts import push_env
@@ -29,22 +27,13 @@ class AwsProfile(SAMLClient):
 
     @classmethod
     def validate_resource(cls, resource: str):
-        config = ConfigParser()
+        config = ConfigParser(strict=False)
         config.read(AwsCredentialsPath)
         return config.has_section(resource)
 
-    @classmethod
-    def check_resource(cls, resource: str):
-        if not cls.validate_resource(resource):
-            config = ConfigParser()
-            config.read(AwsCredentialsPath)
-            raise InvalidResource(
-                resource, config.sections(), resource_name="AWS Profile"
-            )
-
     @cached_property
     def _section(self):
-        config = ConfigParser()
+        config = ConfigParser(strict=False)
         config.read(AwsCredentialsPath)
         return config[self.resource]
 
@@ -65,7 +54,7 @@ class AwsProfile(SAMLClient):
         return AwsCredentialsPath.exists()
 
     def _ensure_config(self, profile: Profile) -> ConfigParser:
-        return ConfigParser()
+        return ConfigParser(strict=False)
 
     def _ensure_session(self, *, force: bool):
         if not force and not self._creds_expiring():
