@@ -59,7 +59,7 @@ class SAMLClient(ABC):
         return self.options.log_dir
 
     @property
-    def session_length(self):
+    def session_length(self) -> Optional[int]:
         return self.options.session_length
 
     @classmethod
@@ -242,8 +242,9 @@ class SAMLClient(ABC):
         self.dprint(f"writing creds, profile={profile}")
 
         if (
-            self._creds_expiring(buffer=timedelta(minutes=10))
-            or self.session_length
+            self._creds_expiring(
+                buffer=timedelta(minutes=(self.session_length or 30) / 3)
+            )
             or not self._profile_matches_caller_identity()
         ):
             self._ensure_session(force=True)
@@ -256,7 +257,7 @@ class SAMLClient(ABC):
         path.parent.mkdir(parents=True, exist_ok=True)
 
         with read_write_lock(path) as f:
-            config = ConfigParser()
+            config = ConfigParser(strict=False)
             config.read_file(f)
 
             if config.has_section(profile):
