@@ -256,9 +256,9 @@ def test_ansible_playbook_send_command(
         }
         ansible_args = [
             "--connection=sym_aws_ssm",
-            "--forks=15",
+            "--forks=10",
             f"--user={get_ssh_user()}",
-            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible $HOST' ansible_aws_ssm_region='us-east-1' ansible_aws_ssm_profile='sym-ansible'",
+            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible-test $HOST --json' ansible_aws_ssm_region='us-east-1' ansible_aws_ssm_profile='sym-ansible-test'",
         ]
         capture_command.assert_commands(
             [
@@ -294,7 +294,7 @@ def test_ansible_playbook_send_command_low_forks(
             "--connection=sym_aws_ssm",
             "--forks=5",
             f"--user={get_ssh_user()}",
-            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible $HOST' ansible_aws_ssm_region='us-east-1' ansible_aws_ssm_profile='sym-ansible'",
+            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible-test $HOST --json' ansible_aws_ssm_region='us-east-1' ansible_aws_ssm_profile='sym-ansible-test'",
         ]
         capture_command.assert_commands(
             [
@@ -309,3 +309,24 @@ def test_ansible_playbook_send_command_low_forks(
                 ),
             ]
         )
+
+
+def test_ansible_no_login(command_login_tester):
+    command_login_tester(["ansible"])
+    command_login_tester(["ansible", "test"])
+    command_login_tester(["ansible"], {"SYM_RESOURCE": "test"})
+    command_login_tester(["ansible"], {"ENVIRONMENT": "test"})
+
+
+def test_ansible_playbook_no_login(command_login_tester):
+    command_login_tester(["ansible-playbook"])
+    command_login_tester(["ansible-playbook", "test"])
+    command_login_tester(
+        ["ansible-playbook", "test", "-i", "inventory.txt", "playbook.yml"]
+    )
+    command_login_tester(["ansible-playbook"], {"SYM_RESOURCE": "test"})
+    command_login_tester(["ansible-playbook"], {"ENVIRONMENT": "test"})
+    command_login_tester(
+        ["ansible-playbook", "-i", "inventory.txt", "playbook.yml"],
+        {"ENVIRONMENT": "test"},
+    )
