@@ -1,6 +1,7 @@
 from multiprocessing import Pool
 
 import pytest
+from expects import *
 
 from sym.cli.saml_clients.aws_okta import AwsOkta
 from sym.cli.tests.helpers.capture import CaptureCommand
@@ -40,6 +41,14 @@ def test_aws_okta_debug(
     )
 
 
+def test_aws_okta_session_length(test_context: TestContextFixture[AwsOkta]):
+    with test_context(debug=False) as aws_okta:
+        aws_okta.options.session_length = 60
+        expect(
+            dict(aws_okta.ensure_config()[f"profile {aws_okta._section_name}"]),
+        ).to(have_key("session_ttl", "60m"))
+
+
 def test_aws_okta_multi_threads(subprocess_friendly_asserter) -> None:
     commands = (
         "aws-okta exec sym-test -- env",
